#[repr(transparent)]pub struct RoomList {
inner: TypedObjectRef<RoomList, ()>,
phantom: PhantomData<()>,
}Expand description
List of all rooms known by the user.
This is the parent GListModel of the sidebar from which all other models
are derived.
The RoomList also takes care of, so called pending rooms, i.e.
rooms the user requested to join, but received no response from the
server yet.
GLib type: GObject with reference counted clone semantics.
Fields
inner: TypedObjectRef<RoomList, ()>phantom: PhantomData<()>Implementations
Sourceimpl RoomList
impl RoomList
Sourcepub fn connect_session_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_session_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Listen for notifications of a change in the session property
Sourcepub fn notify_session(&self)
pub fn notify_session(&self)
Notify listeners of a change in the session property
Sourceimpl RoomList
impl RoomList
pub fn new(session: &Session) -> Self
Sourcepub(crate) fn is_joining_room(&self, identifier: &RoomOrAliasId) -> bool
pub(crate) fn is_joining_room(&self, identifier: &RoomOrAliasId) -> bool
Whether we are currently joining the room with the given identifier.
Sourcepub(crate) fn get(&self, room_id: &RoomId) -> Option<Room>
pub(crate) fn get(&self, room_id: &RoomId) -> Option<Room>
Get the room with the given room ID, if any.
Sourcepub(crate) fn get_by_identifier(
&self,
identifier: &RoomOrAliasId,
) -> Option<Room>
pub(crate) fn get_by_identifier( &self, identifier: &RoomOrAliasId, ) -> Option<Room>
Get the room with the given identifier, if any.
Sourcepub(crate) async fn get_wait(
&self,
room_id: &RoomId,
timeout: Option<Duration>,
) -> Option<Room>
pub(crate) async fn get_wait( &self, room_id: &RoomId, timeout: Option<Duration>, ) -> Option<Room>
Wait till the room with the given ID becomes available.
Sourcepub(crate) fn direct_chat(&self, user_id: &UserId) -> Option<Room>
pub(crate) fn direct_chat(&self, user_id: &UserId) -> Option<Room>
Get the joined room that is a direct chat with the user with the given ID.
If several rooms are found, returns the room with the latest activity.
Sourcepub(crate) fn add_tombstoned_room(&self, room_id: OwnedRoomId)
pub(crate) fn add_tombstoned_room(&self, room_id: OwnedRoomId)
Add a room that was tombstoned but for which we haven’t joined the successor yet.
Sourcepub(crate) fn handle_room_updates(&self, rooms: RoomUpdates)
pub(crate) fn handle_room_updates(&self, rooms: RoomUpdates)
Handle room updates received via sync.
Sourcepub(crate) async fn join_by_id_or_alias(
&self,
identifier: OwnedRoomOrAliasId,
via: Vec<OwnedServerName>,
) -> Result<OwnedRoomId, String>
pub(crate) async fn join_by_id_or_alias( &self, identifier: OwnedRoomOrAliasId, via: Vec<OwnedServerName>, ) -> Result<OwnedRoomId, String>
Join the room with the given identifier.
Sourcepub(crate) async fn knock(
&self,
identifier: OwnedRoomOrAliasId,
via: Vec<OwnedServerName>,
) -> Result<OwnedRoomId, String>
pub(crate) async fn knock( &self, identifier: OwnedRoomOrAliasId, via: Vec<OwnedServerName>, ) -> Result<OwnedRoomId, String>
Request an invite to the room with the given identifier.
Sourcepub fn connect_joining_rooms_changed<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_joining_rooms_changed<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Connect to the signal emitted when the list of rooms we are currently joining changed.